Files
alibaba--mnn/doc/API/html/structhalide__device__interface__t-members.html
2026-07-13 13:33:03 +08:00

72 lines
6.1 KiB
HTML

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=9"/>
<meta name="generator" content="Doxygen 1.8.15"/>
<meta name="viewport" content="width=device-width, initial-scale=1"/>
<title>MNN: 成员列表</title>
<link href="tabs.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="jquery.js"></script>
<script type="text/javascript" src="dynsections.js"></script>
<link href="doxygen.css" rel="stylesheet" type="text/css" />
</head>
<body>
<div id="top"><!-- do not remove this div, it is closed by doxygen! -->
<div id="titlearea">
<table cellspacing="0" cellpadding="0">
<tbody>
<tr style="height: 56px;">
<td id="projectalign" style="padding-left: 0.5em;">
<div id="projectname">MNN
&#160;<span id="projectnumber">1.0</span>
</div>
</td>
</tr>
</tbody>
</table>
</div>
<!-- end header part -->
<!-- 制作者 Doxygen 1.8.15 -->
<script type="text/javascript" src="menudata.js"></script>
<script type="text/javascript" src="menu.js"></script>
<script type="text/javascript">
/* @license magnet:?xt=urn:btih:cf05388f2679ee054f2beb29a391d25f4e673ac3&amp;dn=gpl-2.0.txt GPL-v2 */
$(function() {
initMenu('',false,false,'search.php','搜索');
});
/* @license-end */</script>
<div id="main-nav"></div>
</div><!-- top -->
<div class="header">
<div class="headertitle">
<div class="title">halide_device_interface_t 成员列表</div> </div>
</div><!--header-->
<div class="contents">
<p>成员的完整列表,这些成员属于 <a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a>,包括所有继承而来的类成员</p>
<table class="directory">
<tr class="even"><td class="entry"><a class="el" href="structhalide__device__interface__t.html#af8cf3a57fb9d7b7e5906e5f5a5d87145">buffer_copy</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr><td class="entry"><a class="el" href="structhalide__device__interface__t.html#aa7ec93c5a376610e3e7100e8b389591f">copy_to_device</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr class="even"><td class="entry"><a class="el" href="structhalide__device__interface__t.html#a94496f4e1181af69213ee72ad4e2664a">copy_to_host</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr><td class="entry"><a class="el" href="structhalide__device__interface__t.html#ad22c6f186583b56c91652261e905038f">detach_native</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr class="even"><td class="entry"><a class="el" href="structhalide__device__interface__t.html#adfe1bff4d8a864c6450bfe10adbed304">device_and_host_free</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr><td class="entry"><a class="el" href="structhalide__device__interface__t.html#a0caa167abc636a7c7af4c602496e61cd">device_and_host_malloc</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr class="even"><td class="entry"><a class="el" href="structhalide__device__interface__t.html#a8a091d3679d588771f88172b8a867bd2">device_crop</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr><td class="entry"><a class="el" href="structhalide__device__interface__t.html#ab0bd6619c5acb90929eefa8c94488ebe">device_free</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr class="even"><td class="entry"><a class="el" href="structhalide__device__interface__t.html#aefe045212c1c0cc8993ad77b4c7d793b">device_malloc</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr><td class="entry"><a class="el" href="structhalide__device__interface__t.html#a8d54f5cfdce5abfe5079e746ec6e9a32">device_release</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr class="even"><td class="entry"><a class="el" href="structhalide__device__interface__t.html#a3a61cbd45258f14821c95f9b62d38d29">device_release_crop</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr><td class="entry"><a class="el" href="structhalide__device__interface__t.html#ac7e27bf4acf3d42a41bca1ca15088170">device_sync</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr class="even"><td class="entry"><a class="el" href="structhalide__device__interface__t.html#a0fd396e5aa336a352d86cff51e6099dd">impl</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
<tr><td class="entry"><a class="el" href="structhalide__device__interface__t.html#a165c8b301ca4f0013af7767a63afd753">wrap_native</a></td><td class="entry"><a class="el" href="structhalide__device__interface__t.html">halide_device_interface_t</a></td><td class="entry"></td></tr>
</table></div><!-- contents -->
<!-- start footer part -->
<hr class="footer"/><address class="footer"><small>
制作者 &#160;<a href="http://www.doxygen.org/index.html">
<img class="footer" src="doxygen.png" alt="doxygen"/>
</a> 1.8.15
</small></address>
</body>
</html>